<div align="right">
  <a href="https://travis-ci.org/oscarbranson/latools"><img src="https://travis-ci.org/oscarbranson/latools.svg?branch=master" alt="TravisCI build" height="18"></a>
  <a href="http://latools.readthedocs.io/en/latest/?badge=latest"><img src='http://readthedocs.org/projects/latools/badge/?version=latest' alt='Documentation Status' /></a>
  <a href="https://badge.fury.io/py/latools"><img src="https://badge.fury.io/py/latools.svg" alt="PyPI version" height="18"></a>
</div>


# LAtools
**Python tools for processing Laser Ablation mass spectrometry data**

## Installation
Using `pip`:

    pip install latools

Read the [**User Guide**](http://latools.readthedocs.io) for some info on how to get started. 

## Want to Contribute?
We welcome contributors! You don't even need to be Python-literate - if you have any feedback or suggestions, please open an [issue](https://github.com/oscarbranson/latools/issues) on the GitHub pages, and we'll get to it as soon as we can.

If you're feeling a bit more adventurous, we'd welcome improvements to the code, and particularly the documentation - just create a fork of the project, and get coding! To work on documentation, edit the markdown documents in the [docs/source](https://github.com/oscarbranson/latools/tree/master/docs/source) directory. To edit the code itself, work on the module in the [latools](https://github.com/oscarbranson/latools/blob/master/latools/) directory.

*Join the [mailing list](https://groups.google.com/forum/#!forum/latools) to be kept updated.*